package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/SimpleElementValue.class */
public class SimpleElementValue extends ElementValue {
    private int index;

    public SimpleElementValue(int type, int index, ConstantPool cpool) {
        super(type, cpool);
        this.index = index;
    }

    @Override // org.apache.bcel.classfile.ElementValue
    public void dump(DataOutputStream dos) throws IOException {
        int type = super.getType();
        dos.writeByte(type);
        switch (type) {
            case ElementValue.PRIMITIVE_BYTE /* 66 */:
            case ElementValue.PRIMITIVE_CHAR /* 67 */:
            case ElementValue.PRIMITIVE_DOUBLE /* 68 */:
            case ElementValue.PRIMITIVE_FLOAT /* 70 */:
            case ElementValue.PRIMITIVE_INT /* 73 */:
            case ElementValue.PRIMITIVE_LONG /* 74 */:
            case ElementValue.PRIMITIVE_SHORT /* 83 */:
            case ElementValue.PRIMITIVE_BOOLEAN /* 90 */:
            case ElementValue.STRING /* 115 */:
                dos.writeShort(getIndex());
                return;
            default:
                throw new IllegalStateException("SimpleElementValue doesnt know how to write out type " + type);
        }
    }

    public int getIndex() {
        return this.index;
    }

    public boolean getValueBoolean() {
        if (super.getType() != 90) {
            throw new IllegalStateException("Dont call getValueBoolean() on a non BOOLEAN ElementValue");
        }
        ConstantInteger bo = (ConstantInteger) super.getConstantPool().getConstant(getIndex());
        return bo.getBytes() != 0;
    }

    public byte getValueByte() {
        if (super.getType() != 66) {
            throw new IllegalStateException("Dont call getValueByte() on a non BYTE ElementValue");
        }
        return (byte) super.getConstantPool().getConstantInteger(getIndex()).getBytes();
    }

    public char getValueChar() {
        if (super.getType() != 67) {
            throw new IllegalStateException("Dont call getValueChar() on a non CHAR ElementValue");
        }
        return (char) super.getConstantPool().getConstantInteger(getIndex()).getBytes();
    }

    public double getValueDouble() {
        if (super.getType() != 68) {
            throw new IllegalStateException("Dont call getValueDouble() on a non DOUBLE ElementValue");
        }
        ConstantDouble d = (ConstantDouble) super.getConstantPool().getConstant(getIndex());
        return d.getBytes();
    }

    public float getValueFloat() {
        if (super.getType() != 70) {
            throw new IllegalStateException("Dont call getValueFloat() on a non FLOAT ElementValue");
        }
        ConstantFloat f = (ConstantFloat) super.getConstantPool().getConstant(getIndex());
        return f.getBytes();
    }

    public int getValueInt() {
        if (super.getType() != 73) {
            throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue");
        }
        return super.getConstantPool().getConstantInteger(getIndex()).getBytes();
    }

    public long getValueLong() {
        if (super.getType() != 74) {
            throw new IllegalStateException("Dont call getValueLong() on a non LONG ElementValue");
        }
        ConstantLong j = (ConstantLong) super.getConstantPool().getConstant(getIndex());
        return j.getBytes();
    }

    public short getValueShort() {
        if (super.getType() != 83) {
            throw new IllegalStateException("Dont call getValueShort() on a non SHORT ElementValue");
        }
        ConstantInteger s = (ConstantInteger) super.getConstantPool().getConstant(getIndex());
        return (short) s.getBytes();
    }

    public String getValueString() {
        if (super.getType() != 115) {
            throw new IllegalStateException("Dont call getValueString() on a non STRING ElementValue");
        }
        return super.getConstantPool().getConstantUtf8(getIndex()).getBytes();
    }

    public void setIndex(int index) {
        this.index = index;
    }

    @Override // org.apache.bcel.classfile.ElementValue
    public String stringifyValue() {
        ConstantPool cpool = super.getConstantPool();
        int type = super.getType();
        switch (type) {
            case ElementValue.PRIMITIVE_BYTE /* 66 */:
                ConstantInteger b = cpool.getConstantInteger(getIndex());
                return Integer.toString(b.getBytes());
            case ElementValue.PRIMITIVE_CHAR /* 67 */:
                ConstantInteger ch = cpool.getConstantInteger(getIndex());
                return String.valueOf((char) ch.getBytes());
            case ElementValue.PRIMITIVE_DOUBLE /* 68 */:
                ConstantDouble d = (ConstantDouble) cpool.getConstant(getIndex(), (byte) 6, ConstantDouble.class);
                return Double.toString(d.getBytes());
            case ElementValue.PRIMITIVE_FLOAT /* 70 */:
                ConstantFloat f = (ConstantFloat) cpool.getConstant(getIndex(), (byte) 4, ConstantFloat.class);
                return Float.toString(f.getBytes());
            case ElementValue.PRIMITIVE_INT /* 73 */:
                return Integer.toString(cpool.getConstantInteger(getIndex()).getBytes());
            case ElementValue.PRIMITIVE_LONG /* 74 */:
                ConstantLong j = (ConstantLong) cpool.getConstant(getIndex(), (byte) 5, ConstantLong.class);
                return Long.toString(j.getBytes());
            case ElementValue.PRIMITIVE_SHORT /* 83 */:
                ConstantInteger s = cpool.getConstantInteger(getIndex());
                return Integer.toString(s.getBytes());
            case ElementValue.PRIMITIVE_BOOLEAN /* 90 */:
                ConstantInteger bo = cpool.getConstantInteger(getIndex());
                if (bo.getBytes() == 0) {
                    return "false";
                }
                return "true";
            case ElementValue.STRING /* 115 */:
                return cpool.getConstantUtf8(getIndex()).getBytes();
            default:
                throw new IllegalStateException("SimpleElementValue class does not know how to stringify type " + type);
        }
    }

    @Override // org.apache.bcel.classfile.ElementValue
    public String toString() {
        return stringifyValue();
    }
}
